@@ -18,6 +18,7 @@
  */
 
 
+#define _GNU_SOURCE // strcasestr
 #include <config.h>
 
 
@@ -216,8 +217,8 @@ search_equal_func(GtkTreeModel *model,
                        COL_USER, &user,
                        -1);
 
-    found = !((name && strstr(name, key))
-              || (user && strstr(user, key)));
+    found = !((name && strcasestr(name, key))
+              || (user && strcasestr(user, key)));
 
     g_free(name);
     g_free(user);
@@ -695,14 +696,14 @@ insert_info_to_tree (ProcInfo *info, ProcData *procdata, bool forced = false)
     else
         gtk_tree_store_insert (GTK_TREE_STORE (model), &info->node, NULL, 0);
 
-        gtk_tree_store_set (GTK_TREE_STORE (model), &info->node,
-                            COL_POINTER, info,
-                            COL_NAME, info->name,
-                            COL_ARGS, info->arguments,
-                            COL_TOOLTIP, info->tooltip,
-                            COL_PID, info->pid,
-                            COL_SECURITYCONTEXT, info->security_context,
-                            -1);
+    gtk_tree_store_set (GTK_TREE_STORE (model), &info->node,
+                        COL_POINTER, info,
+                        COL_NAME, info->name,
+                        COL_ARGS, info->arguments,
+                        COL_TOOLTIP, info->tooltip,
+                        COL_PID, info->pid,
+                        COL_SECURITYCONTEXT, info->security_context,
+                        -1);
 
     procdata->pretty_table.set_icon(*info);
 
